.equ BME680_ADR							= 119		; 119 (0x77)

.equ BIT0	=0
.equ BIT1	=1
.equ BIT2	=2
.equ BIT3	=3
.equ BIT4	=4
.equ BIT5	=5
.equ BIT6	=6
.equ BIT7	=7

.equ MODE0		=0
.equ MODE1		=1
.equ osrs_p0	=2
.equ osrs_p1	=3
.equ osrs_p2	=4
.equ osrs_t0	=5
.equ osrs_t1	=6
.equ osrs_t2	=7

.equ FILTER0	=2
.equ FILTER1	=3
.equ FILTER2	=4

.equ BME680_STATUS 			=0x73 	; Reset(01h)
.equ BME680_RESET 			=0xE0
.equ BME680_ID 				=0xD0 	; Reset(61h)
.equ BME680_CONFIG 			=0x75
.equ BME680_Ctrl_MEAS 		=0x74
.equ BME680_Ctrl_HUM 		=0x72
.equ BME680_Ctrl_GAS_1 		=0x71
.equ BME680_Ctrl_GAS_0 		=0x70
.equ BME680_Gas_WAIT_x		=0x64	; Reset(00h) 6Dh64h
.equ BME680_Res_HEAT_x 		=0x5A	; Reset(00h) 63h5Ah
.equ BME680_Idac_HEAT_x 	=0x50	; Reset(00h) 59h50h
.equ BME680_gas_R_lsb 		=0x2B
.equ BME680_gas_R_msb 		=0x2A
.equ BME680_HUM_lsb 		=0x26
.equ BME680_HUM_msb 		=0x25	; Reset(80h)
.equ BME680_TEMP_xlsb 		=0x24
.equ BME680_TEMP_lsb 		=0x23
.equ BME680_TEMP_msb 		=0x22	; Reset(80h)
.equ BME680_PRESS_xlsb 		=0x21
.equ BME680_PRESS_lsb 		=0x20
.equ BME680_PRESS_msb 		=0x1F	; Reset(80h)
.equ BME680_EAS_status		=0x1D
; ##############################################################################
; ##############################################################################
; ##############################################################################
BME680_INITIALISIERUNG:
;-------------------------------------------------------------------------------
; RESET																			
	ldi temp1,(BME680_RESET)
	ldi temp2,(0xB6)
	rcall BME680_REGISTER_WRITE_TEMP1_TEMP2	; Register/Value		
	rcall WAIT_1ms
;-------------------------------------------------------------------------------
; Presence ?																	
	ldi temp1,(BME680_ADR)		; BME680			
	rcall TWI_MT_START_TEMP1	; TX-Start			
	tst ERROR
	breq BME680_PRESENCE
	ldi temp,(ERROR_BME680_NOT_FOUND)
	rcall ANZEIGE_ERROR_TEMP
BME680_PRESENCE:
;-------------------------------------------------------------------------------
; ID korrekt?																	
	ldi temp1,(BME680_ID)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_ID),temp1
	cpi temp1,0x61
	breq BME680_DATA_ID_OK
	ldi temp,(ERROR_BME680_ID)
	rcall ANZEIGE_ERROR_TEMP
BME680_DATA_ID_OK:
;-------------------------------------------------------------------------------
; Datenblatt S.15,16													
;1. Set humidity oversampling to 1x by writing 0b001 to osrs_h<2:0>	
	ldi temp1,(BME680_Ctrl_hum)
	ldi temp2,0b00000001	
	rcall BME680_REGISTER_WRITE_TEMP1_TEMP2	; Register/Value		
;2. Set temperature oversampling to 2x by writing 0b010 to osrs_t<2:0>
;3. Set pressure oversampling to 16x by writing 0b101 to osrs_p<2:0>
	ldi temp1,(BME680_Ctrl_meas)
	ldi temp2,(0<<osrs_T2)|(1<<osrs_T1)|(0<<osrs_T0)|(1<<osrs_P2)|(0<<osrs_P1)|(1<<osrs_P0)|(0<<MODE1)|(0<<MODE0)
	rcall BME680_REGISTER_WRITE_TEMP1_TEMP2	; Register/Value		
; Filter															
	ldi temp1,(BME680_CONFIG)
	ldi temp2,(1<<FILTER2)|(1<<FILTER1)|(1<<FILTER0)
;	rcall BME680_REGISTER_WRITE_TEMP1_TEMP2	; Register/Value		
;4. Set gas_wait_0<7:0> to 0x59 to select 100 ms heat up duration									
;Als nchstes muss der Benutzer mindestens einen Gassensor-Heizplattentemperatursollwert 			
;und eine Heizdauer einstellen. ber die Steuerregister gas_wait_x <7: 0> knnen bis zu 			
;10 Heizdauern konfiguriert werden, wobei x zwischen 0 und 9 liegt. 								
;Die Definition des Registerinhalts finden Sie in Abschnitt 5.3.3. 									
;Die entsprechenden Heizsollwerte werden in den Registern res_heat_x <7: 0> gespeichert. 			
;In Abschnitt 3.3.5 wird erlutert, wie die Zielheiztemperatur umgerechnet wird,					
;z. 300  C in einen Registercode. Fr den Betrieb im erzwungenen Modus wird der verwendete 		
;Heizungssollwert ausgewhlt, indem das Steuerregister nb_conv <3: 0> auf das zu verwendende 		
;Heizprofil gesetzt wird, z. Um gas_wait_0 <7: 0> und res_heat_0 <7: 0> zu verwenden, 				
;muss nb_conv <3: 0> auf 0x0 gesetzt werden. 														
;Schlielich soll die Gasfunktionalitt aktiviert werden, indem das Bit run_gas_l auf 1 gesetzt wird.
	ldi temp1,(BME680_Gas_wait_x)
	ldi temp2,0x59				
	rcall BME680_REGISTER_WRITE_TEMP1_TEMP2	; Register/Value		
;5. Set the corresponding heater set-point by writing the target heater resistance to res_heat_0<7:0>

;6. Set nb_conv<3:0> to 0x0 to select the previously defined heater settings

;7. Set run_gas_l to 1 to enable gas measurements
	ldi temp1,(BME680_Ctrl_gas_1)
	ldi temp2,0b00010000			
	rcall BME680_REGISTER_WRITE_TEMP1_TEMP2	; Register/Value		
;8. Set mode<1:0> to 0b01 to trigger a single measurement.

ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; Set temperature oversampling to 2x by writing 0b010 to osrs_t<2:0>			
; Set pressure oversampling to 16x by writing 0b101 to osrs_p<2:0>				
; Set mode<1:0> to 0b01 to trigger a single measurement.						
BME680_MESSUNG:
	LED_GRUEN_ON
	ldi temp1,(BME680_Ctrl_meas)		; Adresse			
	rcall BME680_REGISTER_READ_TEMP1
;-------------------------------------------------------------------------------
	mov temp2,temp1
	ldi temp1,(BME680_Ctrl_meas)		; Adresse			
	ori temp2,(1<<MODE0)
	rcall BME680_REGISTER_WRITE_TEMP1_TEMP2	; Register/Value		
	rcall WAIT_200ms
	LED_GRUEN_OFF
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; inp: 	temp1 (Register)														
;		temp2 (Value)															
BME680_REGISTER_WRITE_TEMP1_TEMP2:
	push temp2
	push temp1	
	ldi temp1,(BME680_ADR)		; BME680			
	rcall TWI_MT_START_TEMP1	; TX-Start			
	pop temp					; Register			
	rcall TWI_TX_TEMP			; TX				
	pop temp					; VALUE	(temp2)		
	rcall TWI_TX_TEMP			; TX				
	rcall TWI_STOP
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; inp: 	temp1 (Register)														
; out:	temp1 (Value)															
BME680_REGISTER_READ_TEMP1:
	push temp1
	ldi temp1,(BME680_ADR)			; BME680			
	rcall TWI_MT_START_TEMP1		; TX-Start			
	pop temp
	rcall TWI_TX_TEMP				; TX-BME680-Adresse	
	rcall TWI_STOP
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_ADR)			; BME680			
	rcall TWI_RX_START_TEMP1		; RX-START			
	rcall TWI_RX_LAST_BYTES_TEMP1
	rcall TWI_STOP
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
BME680_DATA_READ:
	ldi temp1,(BME680_STATUS)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_STATUS),temp1
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_RESET)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_RESET),temp1
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_ID)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_ID),temp1
	cpi temp1,0x61					; ID=0x61	
	breq BME680_DATA_READ_ID_OK
	ldi temp,(ERROR_BME680_ID)
	rcall ANZEIGE_ERROR_TEMP		; Error		
BME680_DATA_READ_ID_OK:
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_CONFIG)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_CONFIG),temp1
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_Ctrl_MEAS)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_Ctrl_MEAS),temp1
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_Ctrl_HUM)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_Ctrl_HUM),temp1
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_Ctrl_GAS_1)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_Ctrl_GAS_1),temp1
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_Ctrl_GAS_0)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_Ctrl_GAS_0),temp1
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_Gas_WAIT_x)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_Gas_WAIT_x),temp1
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_Res_HEAT_x)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_Res_HEAT_x),temp1
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_Idac_HEAT_x)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_Idac_HEAT_x),temp1
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_gas_R_lsb)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_gas_R_lsb),temp1
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_gas_R_msb)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_gas_R_msb),temp1
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_HUM_lsb)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_HUM_lsb),temp1
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_HUM_msb)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_HUM_msb),temp1
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_TEMP_xlsb)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_TEMP_xlsb),temp1
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_TEMP_lsb)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_TEMP_lsb),temp1
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_TEMP_msb)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_TEMP_msb),temp1
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_PRESS_xlsb)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_PRESS_xlsb),temp1
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_PRESS_lsb)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_PRESS_lsb),temp1
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_PRESS_msb)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_PRESS_msb),temp1
;-------------------------------------------------------------------------------
	ldi temp1,(BME680_EAS_status)
	rcall BME680_REGISTER_READ_TEMP1
	STS(adr_BME680_EAS_status),temp1
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
BME680_ANZEIGE_T:
;-------------------------------------------------------------------------------
;par_t1 E9h EA
	FONT1
	ZEILE0
	ldi temp,'t'
	rcall ASCII_TEMP
	ldi temp,'1'
	rcall ASCII_TEMP
	rcall ASCII_DOPPELPUNKT_SPACE

	ldi temp1,(0xE9)
	rcall BME680_REGISTER_READ_TEMP1
	rcall HEX_TEMP1
	rcall ASCII_SPACE

	ldi temp1,(0xEA)
	rcall BME680_REGISTER_READ_TEMP1
	rcall HEX_TEMP1
;-------------------------------------------------------------------------------
;par_t2 8Ah 8bh
	ZEILE2
	ldi temp,'t'
	rcall ASCII_TEMP
	ldi temp,'2'
	rcall ASCII_TEMP
	rcall ASCII_DOPPELPUNKT_SPACE

	ldi temp1,(0x8A)
	rcall BME680_REGISTER_READ_TEMP1
	rcall HEX_TEMP1
	rcall ASCII_SPACE

	ldi temp1,(0x8b)
	rcall BME680_REGISTER_READ_TEMP1
	rcall HEX_TEMP1
;-------------------------------------------------------------------------------
;par_t3 8ch
	ZEILE4
	ldi temp,'t'
	rcall ASCII_TEMP
	ldi temp,'3'
	rcall ASCII_TEMP
	rcall ASCII_DOPPELPUNKT_SPACE

	ldi temp1,(0x8c)
	rcall BME680_REGISTER_READ_TEMP1
	rcall HEX_TEMP1
;-------------------------------------------------------------------------------
;temp_adc 24h 23h 22h
	ZEILE6
	ldi temp,'a'
	rcall ASCII_TEMP
	ldi temp,'d'
	rcall ASCII_TEMP
	ldi temp,'c'
	rcall ASCII_TEMP
	rcall ASCII_DOPPELPUNKT_SPACE


	LDS temp1,(adr_BME680_TEMP_msb)
	rcall HEX_TEMP1
	rcall ASCII_SPACE	
	LDS temp1,(adr_BME680_TEMP_lsb)
	rcall HEX_TEMP1
	rcall ASCII_SPACE
	LDS temp1,(adr_BME680_TEMP_xlsb)
	rcall HEX_TEMP1
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
